pub struct ListSubaccountsParams {
pub id: i64,
pub label_selector: Option<String>,
pub sort: Option<Vec<String>>,
pub username: Option<String>,
}Expand description
struct for passing parameters to the method list_subaccounts
Fields
id: i64ID of the Storage Box.
label_selector: Option<String>Filter resources by labels. The response will only contain resources matching the label selector. For more information, see "Label Selector".
sort: Option<Vec<String>>Sort resources by field and direction. Can be used multiple times. For more information, see "Sorting".
username: Option<String>Filter Storage Box Subaccounts by username. The response will only contain the resources matching exactly the specified username.