pub struct CreateCertificateRequest {
pub certificate: Option<String>,
pub domain_names: Option<Vec<String>>,
pub labels: Option<HashMap<String, String>>,
pub name: String,
pub private_key: Option<String>,
pub type: Option<Type>,
}Expand description
CreateCertificateRequest : Request for POST https://api.hetzner.cloud/v1/certificates
Fields
certificate: Option<String>Certificate and chain in PEM format, in order so that each record directly certifies the one preceding. Required for type uploaded Certificates.
domain_names: Option<Vec<String>>Domains and subdomains that should be contained in the Certificate issued by Let’s Encrypt. Required for type managed Certificates.
labels: Option<HashMap<String, String>>User-defined labels (key/value pairs) for the Resource. For more information, see "Labels". | User-defined labels (key/value pairs) for the Resource. Note that the set of Labels provided in the request will overwrite the existing one. For more information, see "Labels".
name: StringName of the Certificate.
private_key: Option<String>Certificate key in PEM format. Required for type uploaded Certificates.
type: Option<Type>Choose between uploading a Certificate in PEM format or requesting a managed Let’s Encrypt Certificate.
Implementations
Sourceimpl CreateCertificateRequest
impl CreateCertificateRequest
Sourcepub fn new(name: String) -> CreateCertificateRequest
pub fn new(name: String) -> CreateCertificateRequest
Request for POST https://api.hetzner.cloud/v1/certificates