pub struct CreateStorageBoxRequest {
pub access_settings: Option<Box<CreateStorageBoxRequestAccessSettings>>,
pub labels: Option<HashMap<String, String>>,
pub location: String,
pub name: String,
pub password: String,
pub ssh_keys: Option<Vec<String>>,
pub storage_box_type: String,
}Expand description
CreateStorageBoxRequest : Request for POST https://api.hetzner.com/v1/storage_boxes
Fields
access_settings: Option<Box<CreateStorageBoxRequestAccessSettings>>labels: Option<HashMap<String, String>>User-defined labels (key/value pairs) for the Resource. For more information, see "Labels". | User-defined labels (key/value pairs) for the Resource. Note that the set of Labels provided in the request will overwrite the existing one. For more information, see "Labels".
location: StringID or Name of Location.
name: StringName of the Storage Box.
password: StringPassword of the Storage Box. For more details, see the Storage Boxes password policy.
ssh_keys: Option<Vec<String>>SSH public keys in OpenSSH format to inject into the Storage Box.
storage_box_type: StringID or Name of the Storage Box Type.
Implementations