pub struct EnableSnapshotPlanRequest {
pub day_of_month: Option<Option<i32>>,
pub day_of_week: Option<Option<i32>>,
pub hour: i32,
pub max_snapshots: i32,
pub minute: i32,
}Expand description
EnableSnapshotPlanRequest : Request for POST https://api.hetzner.com/v1/storage_boxes/{id}/actions/enable_snapshot_plan
Fields
day_of_month: Option<Option<i32>>Day of the month when the Snapshot Plan is executed. Null means every day.
day_of_week: Option<Option<i32>>Day of the week when the Snapshot Plan is executed. Starts at 1 for Monday til 7 for Sunday. Null means every day.
hour: i32Hour when the Snapshot Plan is executed (UTC).
max_snapshots: i32Maximum amount of Snapshots that will be created by this Snapshot Plan. Older Snapshots will be deleted.
minute: i32Minute when the Snapshot Plan is executed (UTC).
Implementations