pub struct LoadBalancer {Show 15 fields
pub algorithm: Box<LoadBalancerAlgorithm>,
pub created: String,
pub id: i64,
pub included_traffic: i64,
pub ingoing_traffic: Option<i64>,
pub labels: HashMap<String, String>,
pub load_balancer_type: Box<LoadBalancerType>,
pub location: Box<Location>,
pub name: String,
pub outgoing_traffic: Option<i64>,
pub private_net: Vec<LoadBalancerPrivateNet>,
pub protection: Box<Protection>,
pub public_net: Box<LoadBalancerPublicNet>,
pub services: Vec<LoadBalancerService>,
pub targets: Vec<LoadBalancerTarget>,
}Fields
algorithm: Box<LoadBalancerAlgorithm>created: StringPoint in time when the Resource was created (in RFC3339 format).
id: i64ID of the Load Balancer.
included_traffic: i64Free Traffic for the current billing period in bytes.
ingoing_traffic: Option<i64>Inbound Traffic for the current billing period in bytes.
labels: HashMap<String, String>User-defined labels (key/value pairs) for the Resource. For more information, see "Labels". | User-defined labels (key/value pairs) for the Resource. Note that the set of Labels provided in the request will overwrite the existing one. For more information, see "Labels".
load_balancer_type: Box<LoadBalancerType>location: Box<Location>name: StringName of the Resource. Must be unique per Project.
outgoing_traffic: Option<i64>Outbound Traffic for the current billing period in bytes.
private_net: Vec<LoadBalancerPrivateNet>Private networks information.
protection: Box<Protection>public_net: Box<LoadBalancerPublicNet>services: Vec<LoadBalancerService>List of services that belong to this Load Balancer.
targets: Vec<LoadBalancerTarget>List of targets that belong to this Load Balancer.
Implementations
Sourceimpl LoadBalancer
impl LoadBalancer
pub fn new( algorithm: LoadBalancerAlgorithm, created: String, id: i64, included_traffic: i64, ingoing_traffic: Option<i64>, labels: HashMap<String, String>, load_balancer_type: LoadBalancerType, location: Location, name: String, outgoing_traffic: Option<i64>, private_net: Vec<LoadBalancerPrivateNet>, protection: Protection, public_net: LoadBalancerPublicNet, services: Vec<LoadBalancerService>, targets: Vec<LoadBalancerTarget>, ) -> LoadBalancer