pub struct Server {Show 22 fields
pub backup_window: Option<String>,
pub created: String,
pub id: i64,
pub image: Option<Box<Image>>,
pub included_traffic: Option<i64>,
pub ingoing_traffic: Option<i64>,
pub iso: Option<Box<Iso>>,
pub labels: HashMap<String, String>,
pub load_balancers: Option<Vec<i64>>,
pub location: Box<Location>,
pub locked: bool,
pub name: String,
pub outgoing_traffic: Option<i64>,
pub placement_group: Option<Option<Box<PlacementGroup>>>,
pub primary_disk_size: i32,
pub private_net: Vec<ServerPrivateNet>,
pub protection: Box<ServerProtection>,
pub public_net: Box<ServerPublicNet>,
pub rescue_enabled: bool,
pub server_type: Box<ServerType>,
pub status: Status,
pub volumes: Option<Vec<i64>>,
}Expand description
Server : Servers are virtual machines that can be provisioned.
Fields
backup_window: Option<String>Time window (UTC) in which the backup will run, or null if the backups are not enabled.
created: StringPoint in time when the Resource was created (in RFC3339 format).
id: i64ID of the Server.
image: Option<Box<Image>>Image the server is based on.
included_traffic: Option<i64>Free Traffic for the current billing period in bytes.
ingoing_traffic: Option<i64>Inbound Traffic for the current billing period in bytes.
iso: Option<Box<Iso>>ISO Image that is attached to this Server. Null if no ISO is attached.
labels: HashMap<String, String>User-defined labels (key/value pairs) for the Resource. For more information, see "Labels". | User-defined labels (key/value pairs) for the Resource. Note that the set of Labels provided in the request will overwrite the existing one. For more information, see "Labels".
load_balancers: Option<Vec<i64>>Load Balancer IDs assigned to the server.
location: Box<Location>locked: boolTrue if Server has been locked and is not available to user.
name: StringName of the Server (must be unique per Project and a valid hostname as per RFC 1123).
outgoing_traffic: Option<i64>Outbound Traffic for the current billing period in bytes.
placement_group: Option<Option<Box<PlacementGroup>>>primary_disk_size: i32Size of the primary Disk.
private_net: Vec<ServerPrivateNet>Private networks information.
protection: Box<ServerProtection>public_net: Box<ServerPublicNet>rescue_enabled: boolTrue if rescue mode is enabled. Server will then boot into rescue system on next reboot.
server_type: Box<ServerType>status: StatusStatus of the Server.
volumes: Option<Vec<i64>>IDs of Volumes assigned to this Server.
Implementations
Sourceimpl Server
impl Server
Sourcepub fn new(
backup_window: Option<String>,
created: String,
id: i64,
image: Option<Image>,
included_traffic: Option<i64>,
ingoing_traffic: Option<i64>,
iso: Option<Iso>,
labels: HashMap<String, String>,
location: Location,
locked: bool,
name: String,
outgoing_traffic: Option<i64>,
primary_disk_size: i32,
private_net: Vec<ServerPrivateNet>,
protection: ServerProtection,
public_net: ServerPublicNet,
rescue_enabled: bool,
server_type: ServerType,
status: Status,
) -> Server
pub fn new( backup_window: Option<String>, created: String, id: i64, image: Option<Image>, included_traffic: Option<i64>, ingoing_traffic: Option<i64>, iso: Option<Iso>, labels: HashMap<String, String>, location: Location, locked: bool, name: String, outgoing_traffic: Option<i64>, primary_disk_size: i32, private_net: Vec<ServerPrivateNet>, protection: ServerProtection, public_net: ServerPublicNet, rescue_enabled: bool, server_type: ServerType, status: Status, ) -> Server
Servers are virtual machines that can be provisioned.