pub struct UpdateLoadBalancerService {
pub destination_port: Option<i32>,
pub health_check: Option<Box<UpdateLoadBalancerServiceHealthCheck>>,
pub http: Option<Box<Http>>,
pub listen_port: i32,
pub protocol: Option<Protocol>,
pub proxyprotocol: Option<bool>,
}Expand description
UpdateLoadBalancerService : An update to a service for a Load Balancer.
Fields
destination_port: Option<i32>Port the Load Balancer will balance to.
health_check: Option<Box<UpdateLoadBalancerServiceHealthCheck>>http: Option<Box<Http>>listen_port: i32Port the Load Balancer listens on.
protocol: Option<Protocol>Protocol of the Load Balancer.
proxyprotocol: Option<bool>Is Proxyprotocol enabled or not.
Implementations
Sourceimpl UpdateLoadBalancerService
impl UpdateLoadBalancerService
Sourcepub fn new(listen_port: i32) -> UpdateLoadBalancerService
pub fn new(listen_port: i32) -> UpdateLoadBalancerService
An update to a service for a Load Balancer.